@@ -14,13 +14,13 @@ package che
 import (
 	"context"
 	"fmt"
-	"reflect"
 	"strconv"
 	"time"
 
 	orgv1 "github.com/eclipse/che-operator/pkg/apis/org/v1"
 	"github.com/eclipse/che-operator/pkg/deploy"
 	"github.com/eclipse/che-operator/pkg/util"
+	configv1 "github.com/openshift/api/config/v1"
 	oauthv1 "github.com/openshift/api/config/v1"
 	consolev1 "github.com/openshift/api/console/v1"
 	oauth "github.com/openshift/api/oauth/v1"
@@ -96,6 +96,9 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 		if err := oauthv1.AddToScheme(mgr.GetScheme()); err != nil {
 			logrus.Errorf("Failed to add OpenShift OAuth to scheme: %s", err)
 		}
+		if err := configv1.AddToScheme(mgr.GetScheme()); err != nil {
+			logrus.Errorf("Failed to add OpenShift Config to scheme: %s", err)
+		}
 		if hasConsolelinkObject() {
 			if err := consolev1.AddToScheme(mgr.GetScheme()); err != nil {
 				logrus.Errorf("Failed to add OpenShift ConsoleLink to scheme: %s", err)
@@ -307,6 +310,26 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 		}
 	}
 
+	// Read proxy configuration
+	proxy, err := r.getProxyConfiguration(instance)
+	if err != nil {
+		logrus.Errorf("Error on reading proxy configuration: %v", err)
+		return reconcile.Result{}, err
+	}
+
+	if proxy.TrustedCAMapName != "" {
+		provisioned, err := r.putOpenShiftCertsIntoConfigMap(instance, proxy, clusterAPI)
+		if !provisioned {
+			configMapName := instance.Spec.Server.ServerTrustStoreConfigMapName
+			if err != nil {
+				logrus.Errorf("Error on provisioning config map '%s': %v", configMapName, err)
+			} else {
+				logrus.Infof("Waiting on provisioning config map '%s'", configMapName)
+			}
+			return reconcile.Result{}, err
+		}
+	}
+
 	cheFlavor := deploy.DefaultCheFlavor(instance)
 	cheDeploymentName := cheFlavor
 
@@ -319,7 +342,7 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 	}
 
 	// Detect whether self-signed certificate is used
-	selfSignedCertUsed, err := deploy.IsSelfSignedCertificateUsed(instance, clusterAPI)
+	selfSignedCertUsed, err := deploy.IsSelfSignedCertificateUsed(instance, proxy, clusterAPI)
 	if err != nil {
 		logrus.Errorf("Failed to detect if self-signed certificate used. Cause: %v", err)
 		return reconcile.Result{}, err
@@ -332,7 +355,7 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 			// and NOT from the Openshift API Master URL (as in v3)
 			// So we also need the self-signed certificate to access them (same as the Che server)
 			(isOpenShift4 && instance.Spec.Auth.OpenShiftoAuth && !instance.Spec.Server.TlsSupport) {
-			if err := deploy.CreateTLSSecretFromRoute(instance, "", deploy.CheTLSSelfSignedCertificateSecretName, clusterAPI); err != nil {
+			if err := deploy.CreateTLSSecretFromRoute(instance, "", deploy.CheTLSSelfSignedCertificateSecretName, proxy, clusterAPI); err != nil {
 				return reconcile.Result{}, err
 			}
 		}
@@ -353,7 +376,7 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 			if err != nil {
 				logrus.Errorf("Failed to get OpenShift cluster public hostname. A secret with API crt will not be created and consumed by RH-SSO/Keycloak")
 			} else {
-				if err := deploy.CreateTLSSecretFromRoute(instance, baseURL, "openshift-api-crt", clusterAPI); err != nil {
+				if err := deploy.CreateTLSSecretFromRoute(instance, baseURL, "openshift-api-crt", proxy, clusterAPI); err != nil {
 					return reconcile.Result{}, err
 				}
 			}
@@ -613,6 +636,7 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 			}
 
 			if !tests {
+				identityProviderPostgresPassword := instance.Spec.Auth.IdentityProviderPostgresPassword
 				identityProviderPostgresSecret := instance.Spec.Auth.IdentityProviderPostgresSecret
 				if len(identityProviderPostgresSecret) > 0 {
 					_, password, err := util.K8sclient.ReadSecret(identityProviderPostgresSecret, instance.Namespace)
@@ -620,9 +644,9 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 						logrus.Errorf("Failed to read '%s' secret: %s", identityProviderPostgresSecret, err)
 						return reconcile.Result{Requeue: true, RequeueAfter: time.Second * 5}, err
 					}
-					identityProviderPostgresSecret = password
+					identityProviderPostgresPassword = password
 				}
-				pgCommand := deploy.GetPostgresProvisionCommand(identityProviderPostgresSecret)
+				pgCommand := deploy.GetPostgresProvisionCommand(identityProviderPostgresPassword)
 				dbStatus := instance.Status.DbProvisoned
 				// provision Db and users for Che and Keycloak servers
 				if !dbStatus {
@@ -793,7 +817,7 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 				}
 			}
 
-			deploymentStatus := deploy.SyncKeycloakDeploymentToCluster(instance, clusterAPI)
+			deploymentStatus := deploy.SyncKeycloakDeploymentToCluster(instance, proxy, clusterAPI)
 			if !tests {
 				if !deploymentStatus.Continue {
 					logrus.Info("Waiting on deployment 'keycloak' to be ready")
@@ -838,244 +862,23 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 		}
 	}
 
-	// Create devfile registry resources unless an external registry is used
-	devfileRegistryURL := instance.Spec.Server.DevfileRegistryUrl
-	externalDevfileRegistry := instance.Spec.Server.ExternalDevfileRegistry
-	if !externalDevfileRegistry {
-		registryName := "devfile-registry"
-		host := ""
-		if !isOpenShift {
-			ingressStatus := deploy.SyncIngressToCluster(instance, registryName, registryName, 8080, clusterAPI)
-			if !tests {
-				if !ingressStatus.Continue {
-					logrus.Infof("Waiting on ingress '%s' to be ready", registryName)
-					if ingressStatus.Err != nil {
-						logrus.Error(ingressStatus.Err)
-					}
-
-					return reconcile.Result{Requeue: ingressStatus.Requeue}, ingressStatus.Err
-				}
-			}
-
-			host = ingressDomain
-			if ingressStrategy == "multi-host" {
-				host = registryName + "-" + instance.Namespace + "." + ingressDomain
-			}
-		} else {
-			routeStatus := deploy.SyncRouteToCluster(instance, registryName, registryName, 8080, clusterAPI)
-			if !tests {
-				if !routeStatus.Continue {
-					logrus.Infof("Waiting on route '%s' to be ready", registryName)
-					if routeStatus.Err != nil {
-						logrus.Error(routeStatus.Err)
-					}
-
-					return reconcile.Result{Requeue: routeStatus.Requeue}, routeStatus.Err
-				}
-			}
-
-			if !tests {
-				host = routeStatus.Route.Spec.Host
-				if len(host) < 1 {
-					cheRoute := r.GetEffectiveRoute(instance, routeStatus.Route.Name)
-					host = cheRoute.Spec.Host
-				}
-			}
-		}
-		guessedDevfileRegistryURL := protocol + "://" + host
-		if devfileRegistryURL == "" {
-			devfileRegistryURL = guessedDevfileRegistryURL
-		}
-		devFileRegistryConfigMap := &corev1.ConfigMap{}
-		err = r.client.Get(context.TODO(), types.NamespacedName{Name: "devfile-registry", Namespace: instance.Namespace}, devFileRegistryConfigMap)
-		if err != nil {
-			if errors.IsNotFound(err) {
-				devFileRegistryConfigMap = deploy.CreateDevfileRegistryConfigMap(instance, devfileRegistryURL)
-				err = controllerutil.SetControllerReference(instance, devFileRegistryConfigMap, r.scheme)
-				if err != nil {
-					logrus.Errorf("An error occurred: %v", err)
-					return reconcile.Result{}, err
-				}
-				logrus.Info("Creating devfile registry airgap configmap")
-				err = r.client.Create(context.TODO(), devFileRegistryConfigMap)
-				if err != nil {
-					logrus.Errorf("Error creating devfile registry configmap: %v", err)
-					return reconcile.Result{}, err
-				}
-				return reconcile.Result{Requeue: true}, nil
-			} else {
-				logrus.Errorf("Could not get devfile-registry ConfigMap: %v", err)
-				return reconcile.Result{}, err
-			}
-		} else {
-			newDevFileRegistryConfigMap := deploy.CreateDevfileRegistryConfigMap(instance, devfileRegistryURL)
-			if !reflect.DeepEqual(devFileRegistryConfigMap.Data, newDevFileRegistryConfigMap.Data) {
-				err = controllerutil.SetControllerReference(instance, devFileRegistryConfigMap, r.scheme)
-				if err != nil {
-					logrus.Errorf("An error occurred: %v", err)
-					return reconcile.Result{}, err
-				}
-				logrus.Info("Updating devfile-registry ConfigMap")
-				err = r.client.Update(context.TODO(), newDevFileRegistryConfigMap)
-				if err != nil {
-					logrus.Errorf("Error updating devfile-registry ConfigMap: %v", err)
-					return reconcile.Result{}, err
-				}
-			}
-		}
-
-		// Create a new registry service
-		registryLabels := deploy.GetLabels(instance, registryName)
-		serviceStatus := deploy.SyncServiceToCluster(instance, registryName, []string{"http"}, []int32{8080}, registryLabels, clusterAPI)
-		if !tests {
-			if !serviceStatus.Continue {
-				logrus.Info("Waiting on service '" + registryName + "' to be ready")
-				if serviceStatus.Err != nil {
-					logrus.Error(serviceStatus.Err)
-				}
-
-				return reconcile.Result{Requeue: serviceStatus.Requeue}, serviceStatus.Err
-			}
-		}
-
-		// Deploy devfile registry
-		deploymentStatus := deploy.SyncDevfileRegistryDeploymentToCluster(instance, clusterAPI)
-		if !tests {
-			if !deploymentStatus.Continue {
-				logrus.Info("Waiting on deployment '" + registryName + "' to be ready")
-				if deploymentStatus.Err != nil {
-					logrus.Error(deploymentStatus.Err)
-				}
-
-				return reconcile.Result{Requeue: deploymentStatus.Requeue}, deploymentStatus.Err
-			}
-		}
-	}
-	if devfileRegistryURL != instance.Status.DevfileRegistryURL {
-		instance.Status.DevfileRegistryURL = devfileRegistryURL
-		if err := r.UpdateCheCRStatus(instance, "status: Devfile Registry URL", devfileRegistryURL); err != nil {
-			instance, _ = r.GetCR(request)
-			return reconcile.Result{Requeue: true, RequeueAfter: time.Second * 1}, err
-		}
-	}
-
-	pluginRegistryURL := instance.Spec.Server.PluginRegistryUrl
-	// Create Plugin registry resources unless an external registry is used
-	externalPluginRegistry := instance.Spec.Server.ExternalPluginRegistry
-	if !externalPluginRegistry {
-		if instance.IsAirGapMode() {
-			pluginRegistryConfigMap := &corev1.ConfigMap{}
-			err = r.client.Get(context.TODO(), types.NamespacedName{Name: "plugin-registry", Namespace: instance.Namespace}, pluginRegistryConfigMap)
+	provisioned, err := deploy.SyncDevfileRegistryToCluster(instance, clusterAPI)
+	if !tests {
+		if !provisioned {
 			if err != nil {
-				if errors.IsNotFound(err) {
-					pluginRegistryConfigMap = deploy.CreatePluginRegistryConfigMap(instance)
-					err = controllerutil.SetControllerReference(instance, pluginRegistryConfigMap, r.scheme)
-					if err != nil {
-						logrus.Errorf("An error occurred: %v", err)
-						return reconcile.Result{}, err
-					}
-					logrus.Info("Creating plugin registry airgap configmap")
-					err = r.client.Create(context.TODO(), pluginRegistryConfigMap)
-					if err != nil {
-						logrus.Errorf("Error creating plugin registry configmap: %v", err)
-						return reconcile.Result{}, err
-					}
-					return reconcile.Result{Requeue: true}, nil
-				} else {
-					logrus.Errorf("Could not get plugin-registry ConfigMap: %v", err)
-					return reconcile.Result{}, err
-				}
-			} else {
-				pluginRegistryConfigMap = deploy.CreatePluginRegistryConfigMap(instance)
-				err = controllerutil.SetControllerReference(instance, pluginRegistryConfigMap, r.scheme)
-				if err != nil {
-					logrus.Errorf("An error occurred: %v", err)
-					return reconcile.Result{}, err
-				}
-				logrus.Info(" Updating plugin-registry ConfigMap")
-				err = r.client.Update(context.TODO(), pluginRegistryConfigMap)
-				if err != nil {
-					logrus.Errorf("Error updating plugin-registry ConfigMap: %v", err)
-					return reconcile.Result{}, err
-				}
-			}
-		}
-
-		registryName := "plugin-registry"
-		host := ""
-		if !isOpenShift {
-			ingressStatus := deploy.SyncIngressToCluster(instance, registryName, registryName, 8080, clusterAPI)
-			if !tests {
-				if !ingressStatus.Continue {
-					logrus.Infof("Waiting on ingress '%s' to be ready", registryName)
-					if ingressStatus.Err != nil {
-						logrus.Error(ingressStatus.Err)
-					}
-
-					return reconcile.Result{Requeue: ingressStatus.Requeue}, ingressStatus.Err
-				}
-			}
-
-			host = ingressDomain
-			if ingressStrategy == "multi-host" {
-				host = registryName + "-" + instance.Namespace + "." + ingressDomain
-			}
-		} else {
-			routeStatus := deploy.SyncRouteToCluster(instance, registryName, registryName, 8080, clusterAPI)
-			if !tests {
-				if !routeStatus.Continue {
-					logrus.Infof("Waiting on route '%s' to be ready", registryName)
-					if routeStatus.Err != nil {
-						logrus.Error(routeStatus.Err)
-					}
-
-					return reconcile.Result{Requeue: routeStatus.Requeue}, routeStatus.Err
-				}
-			}
-
-			if !tests {
-				host = routeStatus.Route.Spec.Host
-			}
-		}
-
-		guessedPluginRegistryURL := protocol + "://" + host
-		guessedPluginRegistryURL += "/v3"
-		if pluginRegistryURL == "" {
-			pluginRegistryURL = guessedPluginRegistryURL
-		}
-
-		// Create a new registry service
-		registryLabels := deploy.GetLabels(instance, registryName)
-		serviceStatus := deploy.SyncServiceToCluster(instance, registryName, []string{"http"}, []int32{8080}, registryLabels, clusterAPI)
-		if !tests {
-			if !serviceStatus.Continue {
-				logrus.Info("Waiting on service '" + registryName + "' to be ready")
-				if serviceStatus.Err != nil {
-					logrus.Error(serviceStatus.Err)
-				}
-
-				return reconcile.Result{Requeue: serviceStatus.Requeue}, serviceStatus.Err
-			}
-		}
-
-		// Deploy plugin registry
-		deploymentStatus := deploy.SyncPluginRegistryDeploymentToCluster(instance, clusterAPI)
-		if !tests {
-			if !deploymentStatus.Continue {
-				logrus.Info("Waiting on deployment '" + registryName + "' to be ready")
-				if deploymentStatus.Err != nil {
-					logrus.Error(deploymentStatus.Err)
-				}
-
-				return reconcile.Result{Requeue: deploymentStatus.Requeue}, deploymentStatus.Err
+				logrus.Errorf("Error provisioning '%s' to cluster: %v", deploy.DevfileRegistry, err)
 			}
+			return reconcile.Result{Requeue: true}, err
 		}
 	}
-	if pluginRegistryURL != instance.Status.PluginRegistryURL {
-		instance.Status.PluginRegistryURL = pluginRegistryURL
-		if err := r.UpdateCheCRStatus(instance, "status: Plugin Registry URL", pluginRegistryURL); err != nil {
-			instance, _ = r.GetCR(request)
-			return reconcile.Result{Requeue: true, RequeueAfter: time.Second * 1}, err
+
+	provisioned, err = deploy.SyncPluginRegistryToCluster(instance, clusterAPI)
+	if !tests {
+		if !provisioned {
+			if err != nil {
+				logrus.Errorf("Error provisioning '%s' to cluster: %v", deploy.PluginRegistry, err)
+			}
+			return reconcile.Result{Requeue: true}, err
 		}
 	}
 
@@ -1088,16 +891,14 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 
 	// create Che ConfigMap which is synced with CR and is not supposed to be manually edited
 	// controller will reconcile this CM with CR spec
-	cheEnv := deploy.GetConfigMapData(instance)
-	configMapStatus := deploy.SyncConfigMapToCluster(instance, cheEnv, clusterAPI)
+	cheConfigMap, err := deploy.SyncCheConfigMapToCluster(instance, proxy, clusterAPI)
 	if !tests {
-		if !configMapStatus.Continue {
-			logrus.Infof("Waiting on config map '%s' to be created", cheFlavor)
-			if configMapStatus.Err != nil {
-				logrus.Error(configMapStatus.Err)
+		if cheConfigMap == nil {
+			logrus.Infof("Waiting on config map '%s' to be created", deploy.CheConfigMapName)
+			if err != nil {
+				logrus.Error(err)
 			}
-
-			return reconcile.Result{Requeue: configMapStatus.Requeue}, configMapStatus.Err
+			return reconcile.Result{}, err
 		}
 	}
 
@@ -1107,11 +908,11 @@ func (r *ReconcileChe) Reconcile(request reconcile.Request) (reconcile.Result, e
 	if tests {
 		cmResourceVersion = r.GetEffectiveConfigMap(instance, deploy.CheConfigMapName).ResourceVersion
 	} else {
-		cmResourceVersion = configMapStatus.ConfigMap.ResourceVersion
+		cmResourceVersion = cheConfigMap.ResourceVersion
 	}
 
 	// Create a new che deployment
-	deploymentStatus := deploy.SyncCheDeploymentToCluster(instance, cmResourceVersion, clusterAPI)
+	deploymentStatus := deploy.SyncCheDeploymentToCluster(instance, cmResourceVersion, proxy, clusterAPI)
 	if !tests {
 		if !deploymentStatus.Continue {
 			logrus.Infof("Waiting on deployment '%s' to be ready", cheFlavor)
