@@ -21,6 +21,7 @@ import (
 	"math/rand"
 	"net/http"
 	"os"
+	"regexp"
 	"sort"
 	"strings"
 	"time"
@@ -242,54 +243,6 @@ func getClusterPublicHostnameForOpenshiftV4() (hostname string, err error) {
 	return hostname, nil
 }
 
-func GenerateProxyJavaOpts(proxyURL string, proxyPort string, nonProxyHosts string, proxyUser string, proxyPassword string, proxySecret string, namespace string) (javaOpts string, err error) {
-	if len(proxySecret) > 0 {
-		user, password, err := k8sclient.ReadSecret(proxySecret, namespace)
-		if err == nil {
-			proxyUser = user
-			proxyPassword = password
-		} else {
-			return "", err
-		}
-	}
-
-	proxyHost := strings.TrimLeft(proxyURL, "https://")
-	proxyUserPassword := ""
-	if len(proxyUser) > 1 && len(proxyPassword) > 1 {
-		proxyUserPassword =
-			" -Dhttp.proxyUser=" + proxyUser + " -Dhttp.proxyPassword=" + proxyPassword +
-				" -Dhttps.proxyUser=" + proxyUser + " -Dhttps.proxyPassword=" + proxyPassword
-	}
-	javaOpts =
-		" -Dhttp.proxyHost=" + proxyHost + " -Dhttp.proxyPort=" + proxyPort +
-			" -Dhttps.proxyHost=" + proxyHost + " -Dhttps.proxyPort=" + proxyPort +
-			" -Dhttp.nonProxyHosts='" + nonProxyHosts + "'" + proxyUserPassword
-	return javaOpts, nil
-}
-
-func GenerateProxyEnvs(proxyHost string, proxyPort string, nonProxyHosts string, proxyUser string, proxyPassword string, proxySecret string, namespace string) (proxyUrl string, noProxy string, err error) {
-	if len(proxySecret) > 0 {
-		user, password, err := k8sclient.ReadSecret(proxySecret, namespace)
-		if err == nil {
-			proxyUser = user
-			proxyPassword = password
-		} else {
-			return "", "", err
-		}
-	}
-
-	proxyUrl = proxyHost + ":" + proxyPort
-	if len(proxyUser) > 1 && len(proxyPassword) > 1 {
-		protocol := strings.Split(proxyHost, "://")[0]
-		host := strings.Split(proxyHost, "://")[1]
-		proxyUrl = protocol + "://" + proxyUser + ":" + proxyPassword + "@" + host + ":" + proxyPort
-	}
-
-	noProxy = strings.Replace(nonProxyHosts, "|", ",", -1)
-
-	return proxyUrl, noProxy, nil
-}
-
 func GetDeploymentEnv(deployment *appsv1.Deployment, key string) (value string) {
 	env := deployment.Spec.Template.Spec.Containers[0].Env
 	for i := range env {
@@ -313,3 +266,16 @@ func GetDeploymentEnvVarSource(deployment *appsv1.Deployment, key string) (value
 	}
 	return valueFrom
 }
+
+func GetEnvByRegExp(regExp string) []corev1.EnvVar {
+	var env []corev1.EnvVar
+	for _, e := range os.Environ() {
+		pair := strings.SplitN(e, "=", 2)
+		envName := pair[0]
+		rxp := regexp.MustCompile(regExp)
+		if rxp.MatchString(envName) {
+			env = append(env, corev1.EnvVar{Name: envName, Value: pair[1]})
+		}
+	}
+	return env
+}
\ No newline at end of file
